@@ -65,7 +65,7 @@ def send_survey(data: dict[str, str]) -> int:
     )
 
     try:
-        connection.request("GET", "feedback.py", headers=headers)
+        connection.request("GET", "/feedback.py", headers=headers)
         return connection.getresponse().status
     except Exception:
         return 0
