@@ -166,9 +166,6 @@ class Node:
         '''This function returns a list containing the fields that the resulting relation will have.
         It requires a dictionary where keys are the names of the relations and the values are
         the relation objects.'''
-        if not isinstance(rels, dict):
-            raise TypeError('Can\'t be of None type')
-
         if isinstance(self, Variable):  #FIXME this is ugly
             return list(rels[self.name].header)
         elif isinstance(self, Binary):
@@ -193,7 +190,7 @@ class Node:
                         _fields[i] = _vars[_fields[i]]
                 return _fields
 
-        raise ValueError('What kind of alien object is this?')
+        raise ValueError(_('What kind of alien object is this?'))
 
     def __eq__(self, other): #FIXME
         if not (isinstance(other, node) and self.name == other.name and self.kind == other.kind):
@@ -268,12 +265,12 @@ class Unary(Node):
 
     def get_projection_prop(self) -> List[str]:
         if self.name != PROJECTION:
-            raise ValueError('This is only supported on projection nodes')
+            raise ValueError(_('This is only supported on projection nodes'))
         return [i.strip() for i in self.prop.split(',')]
 
     def set_projection_prop(self, p: List[str]) -> None:
         if self.name != PROJECTION:
-            raise ValueError('This is only supported on projection nodes')
+            raise ValueError(_('This is only supported on projection nodes'))
         self.prop = ','.join(p)
 
     def get_rename_prop(self) -> Dict[str, str]:
@@ -281,7 +278,7 @@ class Unary(Node):
         Returns the dictionary that the rename operation wants
         '''
         if self.name != RENAME:
-            raise ValueError('This is only supported on rename nodes')
+            raise ValueError(_('This is only supported on rename nodes'))
         r = {}
         for i in self.prop.split(','):
             q = i.split(ARROW)
@@ -293,7 +290,7 @@ class Unary(Node):
         Sets the prop field based on the dictionary for renames
         '''
         if self.name != RENAME:
-            raise ValueError('This is only supported on rename nodes')
+            raise ValueError(_('This is only supported on rename nodes'))
         self.prop = ','.join(f'{k}{ARROW}{v}' for k, v in renames.items())
 
 
@@ -314,7 +311,7 @@ def parse_tokens(expression: List[Union[list, str]]) -> Node:
         assert isinstance(expression[0], str)
         if not rtypes.is_valid_relation_name(expression[0]):
             raise ParserException(
-                f'{expression[0]!r} is not a valid relation name')
+                _(f'{expression[0]!r} is not a valid relation name'))
         return Variable(expression[0]) #FIXME Move validation in the object
 
     # Expression from right to left, searching for binary operators
