@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -165,7 +165,7 @@ class Relation:
         internally.
         Will raise an exception if they don't share the same attributes'''
         if not isinstance(other, Relation):
-            raise TypeError('Expected an instance of the same class')
+            raise TypeError(_('Expected an instance of the same class'))
         elif self.header == other.header:
             return other
         elif len(self.header) == len(other.header) and self.header.sharedAttributes(other.header) == len(self.header):
@@ -203,7 +203,7 @@ class Relation:
         '''
 
         if (not isinstance(other, Relation)):
-            raise Exception('Operand must be a relation')
+            raise Exception(_('Operand must be a relation'))
         if self.header.sharedAttributes(other.header) != 0:
             raise Exception(
                 _('Unable to perform product on relations with colliding attributes')
@@ -476,7 +476,7 @@ class Header(tuple):
                 raise Exception(_('"%s" is not a valid attribute name') % i)
 
         if len(self) != len(set(self)):
-            raise Exception('Attribute names must be unique')
+            raise Exception(_('Attribute names must be unique'))
 
     def __repr__(self):
         return "Header(%s)" % super(Header, self).__repr__()
@@ -514,4 +514,4 @@ class Header(tuple):
         try:
             return [self.index(i) for i in param]
         except ValueError as e:
-            raise Exception('One of the fields is not in the relation: %s' % ','.join(param))
+            raise Exception(_('One of the fields is not in the relation: %s') % ','.join(param))
