@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 
 from gettext import gettext as _
 
-from PyQt5 import QtGui, QtWidgets
+from PyQt6 import QtGui, QtWidgets
 
 from relational_gui import rel_edit
 from relational import relation
@@ -141,5 +141,5 @@ def edit_relation(rel=None):
     ui.setupUi(Form)
     Form.setUi(ui)
 
-    Form.exec_()
+    Form.exec()
     return Form.result_relation
