@@ -1,5 +1,5 @@
 # Relational
-# Copyright (C) 2008-2020  Salvo "LtWorf" Tomaselli
+# Copyright (C) 2008-2024  Salvo "LtWorf" Tomaselli
 #
 # Relational is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,9 +16,10 @@
 #
 # author Salvo "LtWorf" Tomaselli <tiposchi@tiscali.it>
 import sys
+import os
 from gettext import gettext as _
 
-from PyQt5 import QtCore, QtWidgets, QtGui
+from PyQt6 import QtCore, QtWidgets, QtGui
 
 from relational import parser, optimizer, rtypes
 from relational.maintenance import UserInterface
@@ -48,6 +49,12 @@ class relForm(QtWidgets.QMainWindow):
         # Creates the UI
         self.ui.setupUi(self)
 
+        if os.path.exists('/usr/share/pixmaps/relational.png'):
+            icon = QtGui.QIcon('/usr/share/pixmaps/relational.png')
+            self.setWindowIcon(icon)
+        else:
+            ... #FIXME set icon on non-linux systems
+
         # Setting fonts for symbols
         f = QtGui.QFont()
         size = f.pointSize()
@@ -74,10 +81,10 @@ class relForm(QtWidgets.QMainWindow):
 
         # Shortcuts
         shortcuts = (
-            (self.ui.lstRelations, QtGui.QKeySequence.Delete, self.unloadRelation),
+            (self.ui.lstRelations, QtGui.QKeySequence.StandardKey.Delete, self.unloadRelation),
             (self.ui.lstRelations, 'Space', lambda: self.printRelation(self.ui.lstRelations.currentItem())),
-            (self.ui.txtQuery, QtGui.QKeySequence.MoveToNextLine, self.next_history),
-            (self.ui.txtQuery, QtGui.QKeySequence.MoveToPreviousLine, self.prev_history),
+            (self.ui.txtQuery, QtGui.QKeySequence.StandardKey.MoveToNextLine, self.next_history),
+            (self.ui.txtQuery, QtGui.QKeySequence.StandardKey.MoveToPreviousLine, self.prev_history),
         )
 
         self.add_shortcuts(shortcuts)
@@ -104,11 +111,10 @@ class relForm(QtWidgets.QMainWindow):
 
     def add_shortcuts(self, shortcuts):
         for widget,shortcut,slot in shortcuts:
-            action = QtWidgets.QAction(self)
+            action = QtGui.QAction(self)
             action.triggered.connect(slot)
             action.setShortcut(QtGui.QKeySequence(shortcut))
-            # I couldn't find the constant
-            action.setShortcutContext(0)
+            action.setShortcutContext(QtCore.Qt.ShortcutContext.WidgetShortcut)
             widget.addAction(action)
 
     def checkVersion(self):
@@ -247,11 +253,11 @@ class relForm(QtWidgets.QMainWindow):
             item = QtWidgets.QTreeWidgetItem()
             for j,k in enumerate(i):
                 if k is None:
-                    item.setBackground(j, QtGui.QBrush(QtCore.Qt.darkRed, QtCore.Qt.Dense4Pattern))
+                    item.setBackground(j, QtGui.QBrush(QtCore.Qt.GlobalColor.darkRed, QtCore.Qt.BrushStyle.Dense4Pattern))
                 elif isinstance(k, (int, float)):
                     item.setForeground(j, QtGui.QPalette().link())
                 elif not isinstance(k, str):
-                    item.setBackground(j, QtGui.QBrush(QtCore.Qt.darkGreen, QtCore.Qt.Dense4Pattern))
+                    item.setBackground(j, QtGui.QBrush(QtCore.Qt.GlobalColor.darkGreen, QtCore.Qt.BrushStyle.Dense4Pattern))
                 item.setText(j, str(k))
             self.ui.table.addTopLevelItem(item)
 
@@ -332,7 +338,7 @@ class relForm(QtWidgets.QMainWindow):
                 self,
                 _("New relation"),
                 _("Insert the name for the new relation"),
-                QtWidgets.QLineEdit.Normal, ''
+                QtWidgets.QLineEdit.EchoMode.Normal, ''
             )
             if res[1] == False:  # or len(res[0]) == 0:
                 return None
